<?php

defined( 'ABSPATH' ) || exit; 
// Try to move all date and time related functions into this file, then see how they can be improved.

/*
 *  Translate month name if possible else just return english month
 *  @param $date string mm-dd-yyyy e.g. 12-25-2016
 *  @param $results wp options (object)
  *  */
function webinarignition_translate_date($date, $results) {
    $split_date = explode('-', $date);
    $d = $split_date[1];
    $m = $split_date[0];
    $y = $split_date[2];

    $translated_months = explode(',', $results->auto_translate_months);
    if ( ! empty($translated_months[$m - 1]) ) {
        $translated_month = trim($translated_months[$m - 1]);
        return "{$d} {$translated_month}, {$y}";
    } else {
        return date('j M, Y', strtotime("{$y}-{$m}-{$d}"));
    }
}
/**
 * @param object $webinar
 * @param string $timeString e.g. 16:20
 * @return string $time;
 */
function webinarignition_auto_custom_time($webinar, $timeString) {

    $tz = '';
    $format = $webinar->time_format;
    $suffix = $webinar->time_suffix;

    // Only display timezone abbreviation for fixed timezone.
    if ( isset($webinar->auto_timezone_type) && $webinar->auto_timezone_type === 'fixed' ) {
        $tz = $webinar->auto_timezone_custom;
    }

    return webinarignition_format_time($timeString, $tz, $format, $suffix);
}

// Attempt to create a function that can be used
// for formatting all time values in this plugin.
/**
 * webinarignition_format_time
 * @param (object) $webinar
 * @param (object) $lead only required for evergreen
 * @return (string)
 */
function webinarignition_display_time($webinar, $lead=null) {

    $timeString = '';
    $tz = '';
    $format = $webinar->time_format;
    $suffix = $webinar->time_suffix;

    if (webinarignition_is_auto($webinar)) {
        if (is_null($lead))
            return '';

        $timeString = explode(' ', $lead->date_picked_and_live)[1];
        $tz = $lead->lead_timezone;
    } else {
        $timeString = date('H:i', strtotime($webinar->webinar_start_time));
        $tz = $webinar->webinar_timezone;
    }

    return webinarignition_format_time($timeString, $tz, $format, $suffix);
}

function webinarignition_format_time($timeString, $tz, $format, $suffix) {

    $format_string = $format === '24hour' ? 'H:i' : 'g:i A';

    $time = date( $format_string, strtotime( $timeString ) );
    $time .= $suffix;

    if ( !empty($tz) ) {
        $time .= " " . WiDateHelpers::get_tz_abbr_from_name($tz);
    }

    return $time;
}


/**
 * webinarignition_format_time
 * @param (object) $webinar
 * @param (object) $lead only required for evergreen
 * @return (string)
 */
function webinarignition_display_date($webinar, $lead=null) {

    $date_format = get_option("date_format");

    if (webinarignition_is_auto($webinar)) {
        if (is_null($lead)) {
            return '';
        }

        $dateTimeString = explode(" ", $lead->date_picked_and_live);

    } else {
        $dateTimeString = '';
    }

    $dateString = $dateTimeString[0];
    $date = date($date_format, strtotime($dateString));

    $date = webinarignition_translate_dm($webinar->auto_translate_months, $date);
    $date = webinarignition_translate_dm($webinar->auto_translate_days, $date, 'days');

    return $date;
}

function webinarignition_event_month($webinar, $lead=null) {

    if (webinarignition_is_auto($webinar)) {
        if (is_null($lead)) {
            return '';
        }

        $dateTimeString = explode(" ", $lead->date_picked_and_live);

    } else {
        $dateTimeString = '';
    }

    return date('M', strtotime($dateTimeString[0]));
}

function webinarignition_event_day($webinar, $lead=null) {

    if (webinarignition_is_auto($webinar)) {
        if (is_null($lead)) {
            return '';
        }

        $dateTimeString = explode(" ", $lead->date_picked_and_live);

    } else {
        $dateTimeString = '';
    }

    return date('d', strtotime($dateTimeString[0]));
}

function webinarignition_get_tzOffset($tzString)
{
    if (empty($tzString)) {
        $tzString = 'Pacific/Samoa'; // Todo why Somoa utc +13 ??
    }

    $tz = new DateTimeZone($tzString);
    $dateTime = new DateTime('now', $tz);
    $offset = $tz->getOffset($dateTime) / 3600;

    return ($offset < 0 ? '' : '+') . $offset;
}



/**
@param (string) $tzName
@return (string)
 */
function webinarignition_get_timezone_offset_by_name($tzName) {
    if (empty($tzName)) {
        // return '' if tz is empty otherwise new \DateTimeZone will error
        return '';
    }

    $tz = new \DateTime('now', new \DateTimeZone($tzName));
    $tz_offset = $tz->format("P");
    $offset_parts = explode(':', $tz_offset);
    $offset = $offset_parts[0];
    if ( (strlen($offset) === 3) && $offset[1] === "0") {
        $offset = str_replace("0", "", $offset_parts[0]);
    }
    return $offset;
}

function webinarignition_get_cs_time_format_string($results) {
    switch ( $results->time_format ) {
        case '24hour':
            $format_string = 'H:i';
            break;
        default:
            $format_string = 'g:i A';
            break;
    }

    return $format_string;
}

// get max time for evergreen custom schedule
function webinarignition_get_cs_max_time($results) {

    if (isset($results->auto_time_1) || isset($results->auto_time_2) || isset($results->auto_time_3)) {

        $csDates = array();
        if ( $results->auto_time_1 !== "no" ) {
            $csDates[] = strtotime( "$results->auto_time_1" );
        }

        if ( $results->auto_time_2 !== "no" ) {
            $csDates[] = strtotime( "$results->auto_time_2" );
        }

        if ( $results->auto_time_3 !== "no" ) {
            $csDates[] = strtotime( "$results->auto_time_3" );
        }

        if ($getMaxTime = max($csDates)) {
            $csMaxTime = date(webinarignition_get_cs_time_format_string($results), $getMaxTime);
        }

        return !empty($csMaxTime) ? $csMaxTime : 0;
    }

    return 0;
}

function webinarignition_format_date_for_ar_service ($format, $timestamp) {
    $formattedDate = '';
    switch($format) {
        case 'MM-DD-YYYY':
            $formattedDate = date('m-d-Y', $timestamp);
            break;
        case 'DD-MM-YYYY':
            $formattedDate = date('d-m-Y', $timestamp);
            break;
        case 'YYYY-MM-DD':
            $formattedDate = date('Y-m-d', $timestamp);
            break;
        default:
            $formattedDate = date('m-d-Y', $timestamp);
            break;
    }
    return $formattedDate;
}

function webinarignition_make_delayed_date($webinar) {

    $dateTime = new DateTime( 'now', new DateTimeZone( 'UTC' ) );
    $offset = intval( $webinar->delayed_day_offset );
    $offset = $offset > 0 ? $offset : abs($offset);
    if ($offset < 0) {
        $offset = abs($offset);
    }

    $dateTime->modify( '+ ' . $offset . ' days' );
    if ( $webinar->delayed_timezone_type !== 'user_specific' ) {
        $dateTime->setTimezone( new DateTimeZone( $webinar->auto_timezone_delayed ) );
    }

    if ( ! empty( $webinar->delayed_blacklisted_dates ) ) {
        $blackListedDatesDelayed = explode(',', str_replace(' ', '', $webinar->delayed_blacklisted_dates));

        while ( in_array($dateTime->format('Y-m-d'), $blackListedDatesDelayed) ) {
            // if the date is blacklisted, just keep adding 1 day until a valid date is found
            $dateTime->modify( '+1 days' );
            if ( $webinar->delayed_timezone_type !== 'user_specific' ) {
                $dateTime->setTimezone( new DateTimeZone( $webinar->auto_timezone_delayed ) );
            }
        }
    }

    return $dateTime;
}

function webinarignition_tz_list()
{
    $zones_array = array();
    $timestamp = time();

    foreach (timezone_identifiers_list() as $key => $zone) {
        $zones_array[$key]['zone'] = $zone;
        $zones_array[$key]['diff_from_GMT'] = webinarignition_get_time_tz($timestamp, $zone, false, false, true);
    }
    return $zones_array;
}

function webinarignition_get_time_tz($time, $timezone, $format = '12hour', $time_suffix = false, $zoneonly = false) {
    $current_timezone = date_default_timezone_get();
    if(!empty($timezone)){
        date_default_timezone_set($timezone);
    }
    
    // Times
    switch ($format) {
        case "12hour":
            $time = date("g:i A", strtotime($time));
            break;
        case "24hour":
            $time = date("H:i", strtotime($time));
            break;
        default:
            break;
    }


    $utc = date('Z', strtotime(($time))) / 60 / 60;
    $utc = $utc > 0 ? '+'.$utc : $utc;

    $formatted_time = ($zoneonly ? "" : $time . " ") . 'UTC' . $utc;

    date_default_timezone_set($current_timezone);
    return $formatted_time;
}

function webinarignition_create_tz_select_list($selected = false)
{
    $region = "";
    ?>
    <select name="webinar_timezone" id="webinar_timezone"
            class="inputField inputFieldDash elem ">
        <?php
        foreach (webinarignition_tz_list() as $key => $timezone) {
        preg_match("%(.*?)/(.*)%", $timezone['zone'], $matches);
        
        if (!empty($matches[1])) {
                $region = $matches[1];
                if ($key != 0) { ?></optgroup><?php } ?>
                <optgroup label="<?php echo $region; ?>">
        <?php } ?>
            <option value="<?php print $timezone['zone'] ?>" <?php
            if ($selected == $timezone['zone']) {
                echo "selected";
            }
            ?>><?php echo !empty($matches[2]) ? "{$matches[2]} ({$timezone['diff_from_GMT']})" : ''; ?></option>
            <?php } ?>
        </optgroup>
    </select>
<?php }

// ####################################
//
//  Translate Days or Months
//
// ####################################

function webinarignition_translate_dm($data, $output = '', $type = 'months')
{
    $data = array_filter(explode(",", $data));
    if ($type == 'months') {
        $englishMonths = array('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December');
        $englishMonthsabbr = array('Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec');

        // String Replace Months
        if (!empty($data)) {
            foreach ($englishMonths as $key => $month) {
                $output = preg_replace("%$month(?=\W)%", $data[$key], $output);
            }
            foreach ($englishMonthsabbr as $key => $month) {
                $output = preg_replace("%$month(?=\W)%", $data[$key], $output);
            }
        }
        return $output;
    }
    if ($type == 'days') {
        $englishDays = array('Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday', 'Sunday');
        $englishDaysabbr = array('Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat', 'Sun');

        if (!empty($data)) {
            foreach ($englishDays as $key => $day) {
                $output = preg_replace("%$day(?=\W)%", $data[$key], $output);
            }
            foreach ($englishDaysabbr as $key => $day) {
                $output = preg_replace("%$day(?=\W)%", $data[$key], $output);
            }
        }

        return $output;
    }


}

// ####################################
//
//  Convert UTC To TZID (Olson Time)
//
// ####################################
function webinarignition_convert_utc_to_tzid($utc)
{
    switch ($utc) {
        case "-11":
            return "US/Samoa";
            break;
        case "-10":
            return "HST";
            break;
        case "-930":
            return "Pacific/Marquesas";
            break;
        case "-9":
            return "America/Adak";
            break;
        case "-8":
            return "America/Anchorage";
            break;
        case "-7":
            return "MST";
            break;
        case "-6":
            return "US/Mountain";
            break;
        case "-5":
            return "EST";
            break;
        case "-430":
            return "America/Caracas";
            break;
        case "-4":
            return "America/New_York";
            break;
        case "-3":
            return "Canada/Atlantic";
            break;
        case "-2":
            return "Atlantic/South_Georgia";
            break;
        case "-1":
            return "Atlantic/Cape_Verde";
            break;
        case "0":
            return "GMT";
            break;
        case "+1":
            return "Europe/London";
            break;
        case "+2":
            return "CET";
            break;
        case "+3":
            return "EET";
            break;
        case "+4":
            return "Asia/Dubai";
            break;
        case "+5":
            return "Indian/Maldives";
            break;
        case "+530":
            return "Asia/Calcutta";
            break;
        case "+545":
            return "Asia/Katmandu";
            break;
        case "+6":
            return "Asia/Dacca";
            break;
        case "+630":
            return "Indian/Cocos";
            break;
        case "+7":
            return "Asia/Bangkok";
            break;
        case "+8":
            return "Hongkong";
            break;
        case "+9":
            return "Japan";
            break;
        case "+930":
            return "Australia/Adelaide";
            break;
        case "+10":
            return "Australia/Melbourne";
            break;
        case "+11":
            return "Asia/Sakhalin";
            break;
        case "+12":
            return "NZ";
            break;
        default:
            return $utc;
    }
}