<?php
defined( 'ABSPATH' ) || exit;

add_action('wp_ajax_webinarignition_get_webinar', 'webinarignition_get_webinar');

function webinarignition_get_webinar() {

    check_ajax_referer( 'webinarignition_ajax_nonce', 'security' );
    $post_input     = filter_input_array(INPUT_POST);
    $webinar        = get_option('webinarignition_campaign_' . $post_input['id'], false);

    if (isset($webinar->air_html)) {
        $webinar->air_html = stripcslashes($webinar->air_html);
    }

    if (isset($webinar->air_btn_copy)) {
        $webinar->air_btn_copy = stripcslashes($webinar->air_btn_copy);
    }

    if (isset($webinar->air_btn_url)) {
        $webinar->air_btn_url = stripcslashes($webinar->air_btn_url);
    }

    wp_send_json_success([
        'webinar' => $webinar,
    ]);
}


add_action('wp_ajax_webinarignition_save_on_air_settings', 'webinarignition_save_on_air_settings');
function webinarignition_save_on_air_settings() {

    check_ajax_referer( 'webinarignition_ajax_nonce', 'security' );
    $post_input     = filter_input_array(INPUT_POST);

    if ( !isset($post_input['id']) || !is_numeric($post_input['id'])) {
        wp_send_json_error( ['error' => 'Invalid Webinar ID'] );
    }

    $optionName = 'webinarignition_campaign_' . trim($post_input['id']);
    $option = get_option($optionName, false);

    $onairStatus = trim($post_input['onair_status']);
    if (!in_array($onairStatus, array('on', 'off'))) {
        wp_send_json_error(array('on air message could not be toggled'));
    }

    $option->air_toggle = $onairStatus;

    if (isset($post_input['air_html'])) {
        $option->air_html = $post_input['air_html'];
    }

    $option->air_btn_copy = trim($post_input['air_btn_copy']);

    $option->air_btn_url = trim($post_input['air_btn_url']);

    $option->air_btn_color = trim($post_input['air_btn_color']);

    update_option($optionName, $option);

    wp_send_json_success();
}


add_action('wp_ajax_webinarignition_toggle_on_air_message', 'webinarignition_toggle_on_air_message');
function webinarignition_toggle_on_air_message() {

    check_ajax_referer( 'webinarignition_ajax_nonce', 'security' );
    $post_input     = filter_input_array(INPUT_POST);
    if ( !isset($post_input['id']) || !is_numeric($post_input['id'])) {
        wp_send_json_error( ['error' => 'Invalid Webinar ID'] );
    }

    $optionName = 'webinarignition_campaign_' . trim($post_input['id']);
    $option = get_option($optionName, false);

    $onairStatus = trim($post_input['onair_status']);
    if (!in_array($onairStatus, array('on', 'off'))) {
        wp_send_json_error(array('on air message could not be toggled'));
    }

    $option->air_toggle = $onairStatus;
    update_option($optionName, $option);

    wp_send_json_success();
}

add_action('wp_ajax_webinarignition_get_leads', 'webinarignition_get_leads');

function webinarignition_get_leads() {

    check_ajax_referer( 'webinarignition_ajax_nonce', 'security' );

    global $wpdb;

    $post_input     = filter_input_array(INPUT_POST);
    if ( !isset($post_input['id']) || !is_numeric($post_input['id'])) {
        wp_send_json_error( ['error' => 'Invalid Webinar ID'] );
    }

    if ( !isset($post_input['webinar_type']) || !in_array($post_input['webinar_type'], ['evergreen', 'live'])) {
        wp_send_json_error( ['error' => 'Invalid Webinar Type'] );
    }

    $table_db_name = $post_input['webinar_type'] === 'evergreen' ? $wpdb->prefix . "webinarignition_leads_evergreen" : $wpdb->prefix . "webinarignition_leads";

    $sql = "
      SELECT *
      FROM {$table_db_name}
      WHERE app_id = %d ";

    if ( !empty($post_input['search_for']) ) {
        $sql .= " AND ( `name` LIKE %s OR `email` LIKE  %s )";
    }

    $sql .= "
      LIMIT %d
      OFFSET %d
    ";

    if ( !empty($post_input['search_for']) ) {
        $preparedSql = $wpdb->prepare( $sql,
            $post_input['id'],
            '%%' . $wpdb->esc_like( $post_input['search_for'] ) . '%%',
            '%%' . $wpdb->esc_like( $post_input['search_for'] ) . '%%',
            $post_input['limit'],
            $post_input['offset']
        );

        $totalQueryLeads = $wpdb->get_var(
            $wpdb->prepare(
                "
                  SELECT COUNT(*)
                  FROM {$table_db_name}
                  WHERE app_id = %d
                  AND `email` LIKE %s
                ",
                $post_input['id'],
                '%%' . $wpdb->esc_like( $post_input['search_for'] ) . '%%'
            )
        );
    } else {
        $preparedSql = $wpdb->prepare( $sql,
            $post_input['id'],
            $post_input['limit'],
            $post_input['offset']
        );
    }

    $leads = $wpdb->get_results($preparedSql, OBJECT);

    $totalLeads = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$table_db_name} WHERE `app_id` = %d", $post_input['id']));
    $totalQueryLeads = isset($totalQueryLeads) ? $totalQueryLeads : $totalLeads;
    $totalAttendedEvent = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$table_db_name} WHERE `app_id` = %d AND `event` = %s ", $post_input['id'], 'Yes'));
    $totalAttendedReplay = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$table_db_name} WHERE `app_id` = %d AND `replay` = %s ", $post_input['id'], 'Yes'));
    $totalOrdered = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$table_db_name} WHERE `app_id` = %d AND `trk2` = %s ", $post_input['id'], 'Yes'));
    $data = array(
        'leads'                     => $leads,
        'total_leads'               => $totalLeads,
        'total_query_leads'         => $totalQueryLeads,
        'total_attended_event'      => $totalAttendedEvent,
        'total_attended_replay'     => $totalAttendedReplay,
        'total_ordered'             => $totalOrdered,
        'number_of_pages'           => ceil($totalQueryLeads / $post_input['limit']),
    );

    wp_send_json_success($data);
}


add_action('wp_ajax_webinarignition_get_questions', 'webinarignition_get_questions');

function webinarignition_get_questions() {

    check_ajax_referer( 'webinarignition_ajax_nonce', 'security' );

    global $wpdb;

    $post_input     = filter_input_array(INPUT_POST);

    if ( !isset($post_input['id']) || !is_numeric($post_input['id'])) {
        wp_send_json_error( ['error' => 'Invalid Webinar ID'] );
    }

    $table_db_name = $wpdb->prefix . 'webinarignition_questions';

    if ( $wpdb->get_var( $wpdb->prepare( "SHOW TABLES LIKE %s", $table_db_name ) ) != $table_db_name ) {
      $table_db_name = $wpdb->prefix . 'webinarignition_questions_new';
    }

    $sql = "
      SELECT *
      FROM {$table_db_name}
      WHERE app_id = %d ";

    if ( !empty($post_input['search_for']) ) {
        $sql .= " AND `email` LIKE %s ";
    }

    $sql .= "
      LIMIT %d
      OFFSET %d
    ";

    if ( !empty($post_input['search_for']) ) {
        $preparedSql = $wpdb->prepare( $sql,
            $post_input['id'],
            '%%' . $wpdb->esc_like( $post_input['search_for'] ) . '%%',
            $post_input['limit'],
            $post_input['offset']
        );

        $totalQueryQuestions = $wpdb->get_var(
            $wpdb->prepare(
                "
                  SELECT COUNT(*)
                  FROM {$table_db_name}
                  WHERE app_id = %d
                  AND `email` LIKE %s
                ",
                $post_input['id'],
                '%%' . $wpdb->esc_like( $post_input['search_for'] ) . '%%'
            )
        );
    } else {
        $preparedSql = $wpdb->prepare( $sql,
            $post_input['id'],
            $post_input['limit'],
            $post_input['offset']
        );
    }

    $questions = $wpdb->get_results($preparedSql, OBJECT);


    $totalQuestions = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$table_db_name} WHERE `app_id` = %d", $post_input['id']));
    $totalQueryQuestions = isset($totalQueryQuestions) ? $totalQueryQuestions : $totalQuestions;
    $totalActiveQuestions = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$table_db_name} WHERE `app_id` = %d AND `status` = %s ", $post_input['id'], 'live'));
    $totalDoneQuestions = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM {$table_db_name} WHERE `app_id` = %d AND `status` = %s ", $post_input['id'], 'done'));

    $data = array(
        'questions'                     => $questions,
        'total_questions'               => $totalQuestions,
        'total_query_questions'         => $totalQueryQuestions,
        'total_active_questions'        => $totalActiveQuestions,
        'total_done_questions'          => $totalDoneQuestions,
        'number_of_pages'               => ceil($totalQueryQuestions / $post_input['limit']),
    );

    wp_send_json_success($data);
}

add_action('wp_ajax_webinarignition_get_users_online', 'webinarignition_get_users_online');

function webinarignition_get_users_online() {

    check_ajax_referer( 'webinarignition_ajax_nonce', 'security' );

    $post_input     = filter_input_array(INPUT_POST);

    global $wpdb;
    $table_db_name = $wpdb->prefix . "webinarignition_users_online";
    // Purge All Who Havent been updated in 5 minutes...
    $currentTime = date("Y-m-d H:i:s");
    $currentTime = strtotime($currentTime);
    $minus5Minutes = date("Y-m-d H:i:s", strtotime('-5 minutes', $currentTime));
    $wpdb->query("DELETE FROM $table_db_name WHERE dt < '$minus5Minutes' ");
    // Count All
    $count = $wpdb->get_var("SELECT COUNT(*) FROM $table_db_name WHERE app_id = {$post_input['webinar_id']}");
    wp_send_json($count);
}
