<?php
/**
 * WebinarIgnition setup
 *
 * @package WebinarIgnition
 * @since   1.9.187
 */

defined( 'ABSPATH' ) || exit;

/**
 * Main WebinarIgnition Class.
 *
 * @class WebinarIgnition
 */
final class WebinarIgnition {

	/**
	 * WebinarIgnition version.
	 *
	 * @var string
	 */
	public $version = '1.9.187';

	/**
	 * The single instance of the class.
	 *
	 * @var WebinarIgnition
	 */
	protected static $_instance = null;

	/**
	 * Main WebinarIgnition Instance.
	 *
	 * Ensures only one instance of WebinarIgnition is loaded or can be loaded.
	 *
	 * @return WebinarIgnition - Main instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * WebinarIgnition Constructor.
	 */
	public function __construct() {
		$this->includes();
		$this->init_hooks();
	}

	/**
	 * Hook into actions and filters.
	 *
	 */
	private function init_hooks() {

		register_activation_hook( WEBINARIGNITION_PLUGIN_FILE, 'webinarignition_installer' );
		load_plugin_textdomain( 'webinarignition', false, 'webinarignition/languages' );

	}





	/**
	 * What type of request is this?
	 *
	 * @param  string $type admin, ajax, cron or frontend.
	 * @return bool
	 */
	private function is_request( $type ) {
		switch ( $type ) {
			case 'admin':
				return is_admin();
			case 'ajax':
				return defined( 'DOING_AJAX' );
			case 'cron':
				return defined( 'DOING_CRON' );
			case 'frontend':
				return ( ! is_admin() ) && ! defined( 'DOING_CRON' );
		}
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	public function includes() {

		include_once WEBINARIGNITION_PATH . 'vendor/autoload.php';

                include_once WEBINARIGNITION_PATH . "inc/wi-activation.php";
                include_once WEBINARIGNITION_PATH . "inc/WebinarIgnition_Logs.php";

                // migrations
                include_once WEBINARIGNITION_PATH . 'inc/migrations.php';

                // Functions
                include_once WEBINARIGNITION_PATH . 'inc/Functions/DateTimeFunctions.php';
                include_once WEBINARIGNITION_PATH . 'inc/Functions/WebinarFunctions.php';
                include_once WEBINARIGNITION_PATH . 'inc/Functions/LeadFunctions.php';

                include_once WEBINARIGNITION_PATH . "inc/Helpers/DateHelpers.php";
                include_once WEBINARIGNITION_PATH . "inc/Functions/extra_functions.php";

                // AJAX Callbacks:
                include_once WEBINARIGNITION_PATH . "inc/callback.php";
                include_once WEBINARIGNITION_PATH . "inc/callback2.php";
                include_once WEBINARIGNITION_PATH . "inc/callback3.php";

                // Email service integration
                include_once WEBINARIGNITION_PATH . "inc/email_service_integration.php";

                include_once WEBINARIGNITION_PATH . "inc/autowebinar_get_dates.php";

                // Image Uploader:
                include_once WEBINARIGNITION_PATH . "inc/image.php";

                // Menu Here:
                include_once WEBINARIGNITION_PATH . "inc/menu.php";

                // Dashboard:
                include_once WEBINARIGNITION_PATH . "UI/index.php";

                // Page Link:
                include_once WEBINARIGNITION_PATH . "inc/page_link.php";

                // NEW :: Shortcode Widget
                include_once WEBINARIGNITION_PATH . "inc/shortcode_widget.php";


		if ( $this->is_request( 'admin' ) ) {
			include_once WEBINARIGNITION_PATH . 'inc/wi-admin-functions.php';
		}

		if ( $this->is_request( 'frontend' ) ) {

			$this->frontend_includes();
		}

	}



	/**
	 * Include required frontend files.
	 */
	public function frontend_includes() {

		include_once WEBINARIGNITION_PATH . 'inc/wi-frontend-functions.php';

	}

	/**
	 * Function used to Init WebinarIgnition Template Functions - This makes them pluggable by plugins and themes.
	 */
	public function include_template_functions() {
//		include_once WEBINARIGNITION_PATH . 'inc/wi-template-functions.php';
	}

	/**
	 * Init WebinarIgnition when WordPress Initialises.
	 */
	public function init() {
//		// Init action.
//		do_action( 'webinarignition_init' );
	}

	/**
	 * Get the template path.
	 *
	 * @return string
	 */
	public function template_path() {
		return apply_filters( 'webinarignition_template_path', 'webinarignition/' );
	}

	/**
	 * Get Ajax URL.
	 *
	 * @return string
	 */
	public function ajax_url() {
		return admin_url( 'admin-ajax.php', 'relative' );
	}


	/**
	 * Ran when any plugin is activated.
	 *
	 */
	public function activated_plugin( $filename ) {

	}

	/**
	 * Ran when any plugin is deactivated.
	 *
	 */
	public function deactivated_plugin( $filename ) {

	}

}
